<?php
/**
 * Style registry - Auto-generated by build process.
 * Do not edit this file manually.
 *
 * @package wp
 */

return array(
	array(
		'handle' => 'wp-block-directory',
		'path' => 'block-directory/style',
		'dependencies' => array('wp-block-editor', 'wp-components', 'wp-editor'),
	),
	array(
		'handle' => 'wp-block-editor',
		'path' => 'block-editor/style',
		'dependencies' => array('wp-commands', 'wp-components', 'wp-preferences'),
	),
	array(
		'handle' => 'wp-block-library',
		'path' => 'block-library/style',
		'dependencies' => array('wp-block-editor', 'wp-components', 'wp-patterns'),
	),
	array(
		'handle' => 'wp-commands',
		'path' => 'commands/style',
		'dependencies' => array('wp-components'),
	),
	array(
		'handle' => 'wp-components',
		'path' => 'components/style',
		'dependencies' => array(),
	),
	array(
		'handle' => 'wp-customize-widgets',
		'path' => 'customize-widgets/style',
		'dependencies' => array('wp-block-editor', 'wp-block-library', 'wp-components', 'wp-media-utils', 'wp-preferences', 'wp-widgets'),
	),
	array(
		'handle' => 'wp-edit-post',
		'path' => 'edit-post/style',
		'dependencies' => array('wp-block-editor', 'wp-block-library', 'wp-commands', 'wp-components', 'wp-editor', 'wp-preferences', 'wp-widgets'),
	),
	array(
		'handle' => 'wp-edit-site',
		'path' => 'edit-site/style',
		'dependencies' => array('wp-block-editor', 'wp-block-library', 'wp-commands', 'wp-components', 'wp-editor', 'wp-patterns', 'wp-preferences', 'wp-widgets'),
	),
	array(
		'handle' => 'wp-edit-widgets',
		'path' => 'edit-widgets/style',
		'dependencies' => array('wp-block-editor', 'wp-block-library', 'wp-components', 'wp-media-utils', 'wp-patterns', 'wp-preferences', 'wp-widgets'),
	),
	array(
		'handle' => 'wp-editor',
		'path' => 'editor/style',
		'dependencies' => array('wp-block-editor', 'wp-commands', 'wp-components', 'wp-media-utils', 'wp-patterns', 'wp-preferences'),
	),
	array(
		'handle' => 'wp-format-library',
		'path' => 'format-library/style',
		'dependencies' => array('wp-block-editor', 'wp-components'),
	),
	array(
		'handle' => 'wp-list-reusable-blocks',
		'path' => 'list-reusable-blocks/style',
		'dependencies' => array('wp-components'),
	),
	array(
		'handle' => 'wp-media-utils',
		'path' => 'media-utils/style',
		'dependencies' => array('wp-components'),
	),
	array(
		'handle' => 'wp-nux',
		'path' => 'nux/style',
		'dependencies' => array('wp-components'),
	),
	array(
		'handle' => 'wp-patterns',
		'path' => 'patterns/style',
		'dependencies' => array('wp-block-editor', 'wp-components'),
	),
	array(
		'handle' => 'wp-preferences',
		'path' => 'preferences/style',
		'dependencies' => array('wp-components'),
	),
	array(
		'handle' => 'wp-reusable-blocks',
		'path' => 'reusable-blocks/style',
		'dependencies' => array('wp-block-editor', 'wp-components'),
	),
	array(
		'handle' => 'wp-widgets',
		'path' => 'widgets/style',
		'dependencies' => array('wp-block-editor', 'wp-components'),
	),
);
